#define INCL_DOSQUEUES /* For Queue commands */
#define INCL_DOSSESMGR /* For DosStartSession */
#define INCL_DOSMEMMGR /* For DosFreeMem */

#include <os2.h>
#include <stdio.h>     /* For printf */
#include <memory.h>    /* For memset */

#define QNAME "\\QUEUES\\THEOS2.QUE"

typedef struct _CHILDINFO {  /* Define a structure for the queue data */
   USHORT usSessionID;
   USHORT usReturn;
}   CHILDINFO;

int OS2Execute( const char *prog, const char **args )
{
    HQUEUE hqQueue;          /* Queue handle */
    REQUESTDATA rdRequest;   /* Request data for the queue */
    ULONG ulSzData;          /* Size of the queue data */
    BYTE bPriority;          /* For the queue */
    PVOID pvData;            /* Pointer to the queue data */
    STARTDATA sd;            /* Start Data for DosStartSession */
    PID pid;                 /* PID for the started child session */
    ULONG ulSession;         /* Session ID for the child session */
    APIRET rc;               /* Return code from API's */

    memset(&sd,0,sizeof(STARTDATA));  /* Clear the STARTDATA structure,
                                         so we only initialize the values we care about */
    sd.Length = sizeof(STARTDATA);    /* Set size of STARTDATA, use the default */
    sd.Related = SSF_RELATED_CHILD;   /* Start a child session */
    sd.PgmName=prog;  /* Name and path of the app to start */
    sd.TermQ=QNAME;       /* Name of the termination queue */

     /* Create a queue */
    if(!(rc = DosCreateQueue(&hqQueue, QUE_FIFO | QUE_CONVERT_ADDRESS,QNAME)))
    {
        /* Start the child session */
        if(!(rc=DosStartSession(&sd, &ulSession, &pid)))
        {
            /* Print the session ID for the child session */
            printf("SessionID: %d\n",(USHORT)ulSession);
            /* Wait for the child session to end (you'll have to end it in some other way */

            if(!(rc=DosReadQueue(hqQueue, &rdRequest, &ulSzData, &pvData, 0, 0, &bPriority, 0)))
            {
                /* Print the session ID read from the queue */
                printf("SessionID: %d\n", ((CHILDINFO*)pvData)->usSessionID);
                /* Free the memory of the queue data element read */
                DosFreeMem(pvData);
            }
            else
            {
                printf("Error in DosReadQueue: %d", (int)rc);
            }
        }
        else
        {
            printf("Error in DosStartSession: %d\n", (int)rc);
        }
        DosCloseQueue(hqQueue);
    }
    else
    {
        printf("Error in DosCreateQueue: %d\n", (int)rc);
    }
    return 0;
}
